# Generated by Django 3.2 on 2021-07-21 09:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('browsing', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='BrowsConf',
        ),
    ]
